Welcome to mirror list, hosted at ThFree Co, Russian Federation.

dev.gajim.org/gajim/gajim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorwurstsalat <mailtrash@posteo.de>2023-05-22 00:56:44 +0300
committerwurstsalat <mailtrash@posteo.de>2023-05-22 00:56:57 +0300
commita7c7b9d3cc7aa0c2218f049ff36d664bc3430370 (patch)
treeb47ed923b3d2d16b9d5b26dc4ac9820f47ea4d13
parent54e1e89eaafb8659e1965bf8f6756e0eb37f9129 (diff)
cfix: XMLConsole: Set filtering attributes correctly
-rw-r--r--gajim/gtk/xml_console.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/gajim/gtk/xml_console.py b/gajim/gtk/xml_console.py
index 16806201b..6b10dc75e 100644
--- a/gajim/gtk/xml_console.py
+++ b/gajim/gtk/xml_console.py
@@ -462,7 +462,7 @@ class XMLConsoleWindow(Gtk.ApplicationWindow, EventHelper):
tag.set_property('invisible', account != value)
def _on_setting(self, value: bool, data: str) -> None:
- setattr(self, data, value)
+ setattr(self, f'_{data}', value)
value = not value
table = self._ui.protocol_view.get_buffer().get_tag_table()
tag = table.lookup(data)
@@ -515,13 +515,13 @@ class XMLConsoleWindow(Gtk.ApplicationWindow, EventHelper):
elif stanza.startswith('<r') or stanza.startswith('<a'):
type_ = 'stream'
- stanza = '<!-- {kind} {time} ({account}) -->\n{stanza}\n\n'.format(
+ text = '<!-- {kind} {time} ({account}) -->\n{stanza}\n\n'.format(
kind=kind.capitalize(),
time=time.strftime('%c'),
account=account_label,
stanza=stanza)
buffer_.insert_with_tags_by_name(
end_iter, stanza, type_, kind, event.account)
if is_at_the_end:
GLib.idle_add(scroll_to_end, self._ui.scrolled)
@@ -515,13 +515,13 @@ class XMLConsoleWindow(Gtk.ApplicationWindow, EventHelper):
stanza=stanza)
buffer_.insert_with_tags_by_name(
- end_iter, stanza, type_, kind, event.account)
+ end_iter, text, type_, kind, event.account)
if is_at_the_end:
GLib.idle_add(scroll_to_end, self._ui.scrolled)